"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _fetchJsonLd = _interopRequireDefault(require("./fetchJsonLd"));

test("fetch a JSON-LD document", function () {
  fetch.mockResponseOnce("{\n    \"@context\": \"http://json-ld.org/contexts/person.jsonld\",\n    \"@id\": \"http://dbpedia.org/resource/John_Lennon\",\n    \"name\": \"John Lennon\",\n    \"born\": \"1940-10-09\",\n    \"spouse\": \"http://dbpedia.org/resource/Cynthia_Lennon\"\n}", {
    status: 200,
    statusText: "OK",
    headers: new Headers({
      "Content-Type": "application/ld+json"
    })
  });
  return (0, _fetchJsonLd["default"])("/foo.jsonld").then(function (data) {
    expect(data.response.ok).toBe(true);
    expect(data.body.name).toBe("John Lennon");
  });
});
test("fetch a non JSON-LD document", function () {
  fetch.mockResponseOnce("<body>Hello</body>", {
    status: 200,
    statusText: "OK",
    headers: new Headers({
      "Content-Type": "text/html"
    })
  });
  return (0, _fetchJsonLd["default"])("/foo.jsonld")["catch"](function (data) {
    expect(data.response.ok).toBe(true);
    expect((0, _typeof2["default"])(data.body)).toBe("undefined");
  });
});
test("fetch an error", function () {
  fetch.mockResponseOnce("{\n    \"@context\": \"http://json-ld.org/contexts/person.jsonld\",\n    \"@id\": \"http://dbpedia.org/resource/John_Lennon\",\n    \"name\": \"John Lennon\",\n    \"born\": \"1940-10-09\",\n    \"spouse\": \"http://dbpedia.org/resource/Cynthia_Lennon\"\n}", {
    status: 400,
    statusText: "Bad Request",
    headers: new Headers({
      "Content-Type": "application/ld+json"
    })
  });
  return (0, _fetchJsonLd["default"])("/foo.jsonld")["catch"](function (_ref) {
    var response = _ref.response;
    response.json().then(function (body) {
      expect(response.ok).toBe(false);
      expect(body.born).toBe("1940-10-09");
    });
  });
});
test("fetch an empty document", function () {
  fetch.mockResponseOnce("", {
    status: 204,
    statusText: "No Content",
    headers: new Headers({
      "Content-Type": "text/html"
    })
  });
  return (0, _fetchJsonLd["default"])("/foo.jsonld").then(function (data) {
    expect(data.response.ok).toBe(true);
    expect(data.body).toBe(undefined);
  });
});